==> lxqt-panel-1.2.1-1.src.tar.gz: lxqt-panel-1.2.1/plugin-customcommand/translations/customcommand_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="176"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Mukautetun komennon asetukset</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Näkymä</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Use icon from theme or browse file</source>
        <translation>Käytä teeman kuvaketta tai selaa tiedostoa</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Suorita lisäämällä &quot;bash -c&quot; komennon alkuun</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="45"/>
        <source>Select Font</source>
        <translation>Valitse fontti</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="55"/>
        <source>Text</source>
        <translation>Teksti</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="65"/>
        <source>Command</source>
        <translation>Komento</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="75"/>
        <source>Font</source>
        <translation>Fontti</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="82"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="101"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
        <source>Use %1 to display command output</source>
        <translation>Käytä %1 komennon tuloksen näyttämiseen</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="111"/>
        <source>Icon</source>
        <translation>Kuvake</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="121"/>
        <source>Browse</source>
        <translation>Hae</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="131"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Kierrä automaattisesti kun paneeli on pystysuorassa</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="150"/>
        <source>echo Configure...</source>
        <translation>echo Configure...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="153"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="271"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="285"/>
        <source>Command to run</source>
        <translation>Suoritettava komento</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="160"/>
        <source>Max Width</source>
        <translation>Enimmäisleveys</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="212"/>
        <source>Repeat command after:</source>
        <translation>Toista komento viiveellä:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
        <source> second(s)</source>
        <translation> sekunti(a)</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="255"/>
        <source>Mouse Commands</source>
        <translation>Hiirikomennot</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="261"/>
        <source>Click</source>
        <translation>Napsautus</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
        <source>Wheel Up</source>
        <translation>Vieritys ylös</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="302"/>
        <source>Wheel Down</source>
        <translation>Vieritys alas</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
        <source>Select Icon File</source>
        <translation>Valitse kuvaketiedosto</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Kuvat (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>

==> lxqt-panel-1.4.0-1.src.tar.gz: lxqt-panel-1.4.0/plugin-customcommand/translations/customcommand_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="186"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Mukautetun komennon asetukset</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Ulkoasu</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
        <source>Use icon from theme or browse file</source>
        <translation>Käytä teeman kuvaketta tai selaa tiedostoa</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="188"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Suorita lisäämällä &quot;bash -c&quot; komennon alkuun</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
        <source>Select Font</source>
        <translation>Valitse fontti</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
        <source>Text</source>
        <translation>Teksti</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="135"/>
        <source>Command</source>
        <translation>Komento</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="128"/>
        <source>Font</source>
        <translation>Fontti</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="162"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
        <source>Use %1 to display command output</source>
        <translation>Käytä %1 komennon tuloksen näyttämiseen</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="145"/>
        <source>Icon</source>
        <translation>Kuvake</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="108"/>
        <source>Browse</source>
        <translation>Selaa</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="155"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Kierrä automaattisesti kun paneeli on pystysuorassa</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="240"/>
        <source>echo Configure...</source>
        <translation>echo Määritä...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="243"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="285"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
        <source>Command to run</source>
        <translation>Suoritettava komento</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="118"/>
        <source>Max Width</source>
        <translation>Enimmäisleveys</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="70"/>
        <source>Repeat command after:</source>
        <translation>Toista komento viiveellä:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="86"/>
        <source> second(s)</source>
        <translation> sekunti(a)</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="250"/>
        <source>Command outputs an image</source>
        <translation>Komento tulostaa kuvan</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="262"/>
        <source>Mouse Commands</source>
        <translation>Hiirikomennot</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
        <source>Click</source>
        <translation>Napsautus</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="299"/>
        <source>Wheel Up</source>
        <translation>Vieritys ylös</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="309"/>
        <source>Wheel Down</source>
        <translation>Vieritys alas</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
        <source>Select Icon File</source>
        <translation>Valitse kuvaketiedosto</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Kuvat (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>
